import{n as t,D as d,j as c,aD as l,aE as g,A as e}from"./index.DXat8gQf.js";const f=t("iframe",{target:"etgi5ab0"})(({theme:o,disableScrolling:i})=>({colorScheme:"normal",border:"none",padding:o.spacing.none,margin:o.spacing.none,overflow:i?"hidden":void 0}));function E({element:o,width:i}){const s=o.hasWidth?o.width:i,n=r(o.src),a=d(n)?void 0:r(o.srcdoc);return c(f,{className:"stIFrame","data-testid":"stIFrame",allow:l,disableScrolling:!o.scrolling,src:n,srcDoc:a,width:s,height:o.height,scrolling:o.scrolling?"auto":"no",sandbox:g,title:"st.iframe"})}function r(o){return e(o)||o===""?void 0:o}export{E as default};
