import{r as i,E as W,_ as $,n as d,a5 as L,M as V,j as a,a8 as D,aY as K}from"./index.DXat8gQf.js";import{I as N}from"./InputInstructions.BohKIZFT.js";import{i as _}from"./inputUtils.CQWz5UKz.js";import{T as M}from"./textarea.B7FAzJHc.js";import"./base-input.CTx0gvzT.js";var R=i.forwardRef(function(t,r){var l={fill:"currentColor",xmlns:"http://www.w3.org/2000/svg"};return i.createElement(W,$({iconAttrs:l,iconVerticalAlign:"middle",iconViewBox:"0 0 24 24"},t,{ref:r}),i.createElement("rect",{width:24,height:24,fill:"none"}),i.createElement("path",{d:"M3 5.51v3.71c0 .46.31.86.76.97L11 12l-7.24 1.81c-.45.11-.76.51-.76.97v3.71c0 .72.73 1.2 1.39.92l15.42-6.49c.82-.34.82-1.5 0-1.84L4.39 4.58C3.73 4.31 3 4.79 3 5.51z"}))});R.displayName="Send";const j=d("div",{target:"e1ur7if90"})(({theme:t,width:r})=>({borderRadius:t.radii.xxxl,display:"flex",backgroundColor:t.colors.widgetBackgroundColor??t.colors.secondaryBg,width:`${r}px`})),A=d("div",{target:"e1ur7if91"})(({theme:t})=>({backgroundColor:t.colors.transparent,position:"relative",flexGrow:1,borderRadius:t.radii.xxxl,display:"flex",alignItems:"center"})),F=d("button",{target:"e1ur7if92"})(({theme:t,disabled:r,extended:l})=>{const u=L(t),[o,g]=u?[t.colors.gray60,t.colors.gray80]:[t.colors.gray80,t.colors.gray40];return{border:"none",backgroundColor:t.colors.transparent,borderTopRightRadius:l?"0":t.radii.xxxl,borderTopLeftRadius:l?t.radii.default:"0",borderBottomRightRadius:t.radii.xxxl,display:"inline-flex",alignItems:"center",justifyContent:"center",lineHeight:t.lineHeights.none,margin:t.spacing.none,padding:t.spacing.sm,color:r?o:g,pointerEvents:"auto","&:focus":{outline:"none"},":focus":{outline:"none"},"&:focus-visible":{backgroundColor:u?t.colors.gray10:t.colors.gray90},"&:hover":{color:t.colors.primary},"&:disabled, &:disabled:hover, &:disabled:active":{backgroundColor:t.colors.transparent,borderColor:t.colors.transparent,color:t.colors.gray}}}),G=d("div",{target:"e1ur7if93"})({display:"flex",alignItems:"flex-end",height:"100%",position:"absolute",right:0,pointerEvents:"none"}),U=d("div",{target:"e1ur7if94"})(({theme:t})=>({position:"absolute",bottom:"0px",right:`calc(${t.iconSizes.xl} + 2 * ${t.spacing.sm} + ${t.spacing.sm})`})),O=6.5,H=1;function Z({width:t,element:r,widgetMgr:l,fragmentId:u}){const o=V(),[g,h]=i.useState(!1),[p,f]=i.useState(r.default),[x,y]=i.useState(0),s=i.useRef(null),b=i.useRef({minHeight:0,maxHeight:0}),E=()=>{let e=0;const{current:n}=s;if(n){const c=n.placeholder;n.placeholder="",n.style.height="auto",e=n.scrollHeight,n.placeholder=c,n.style.height=""}return e},C=()=>{s.current&&s.current.focus(),p&&(l.setStringTriggerValue(r,p,{fromUi:!0},u),h(!1),f(""),y(0))},w=e=>{const{metaKey:n,ctrlKey:c,shiftKey:z}=e;_(e)&&!z&&!c&&!n&&(e.preventDefault(),C())},k=e=>{const{value:n}=e.target,{maxChars:c}=r;c!==0&&n.length>c||(h(n!==""),f(n),y(E()))};i.useEffect(()=>{if(r.setValue){r.setValue=!1;const e=r.value||"";f(e),h(e!=="")}},[r]),i.useEffect(()=>{if(s.current){const{offsetHeight:e}=s.current;b.current.minHeight=e,b.current.maxHeight=e*O}},[s]);const{disabled:I,placeholder:m,maxChars:B}=r,{minHeight:T,maxHeight:S}=b.current,v=x>0&&s.current?Math.abs(x-T)>H:!1;return a(j,{className:"stChatInput","data-testid":"stChatInput",width:t,children:D(A,{children:[a(M,{inputRef:s,value:p,placeholder:m,onChange:k,onKeyDown:w,"aria-label":m,disabled:I,rows:1,overrides:{Root:{style:{minHeight:o.sizes.minElementHeight,outline:"none",backgroundColor:o.colors.transparent,borderRadius:o.radii.xxxl,borderLeftWidth:o.sizes.borderWidth,borderRightWidth:o.sizes.borderWidth,borderTopWidth:o.sizes.borderWidth,borderBottomWidth:o.sizes.borderWidth,width:`${t}px`}},InputContainer:{style:{backgroundColor:o.colors.transparent}},Input:{props:{"data-testid":"stChatInputTextArea"},style:{lineHeight:o.lineHeights.inputWidget,backgroundColor:o.colors.transparent,resize:"none","::placeholder":{opacity:"0.7"},height:v?`${x+H}px`:"auto",maxHeight:S?`${S}px`:"none",paddingLeft:o.spacing.lg,paddingBottom:o.spacing.sm,paddingTop:o.spacing.sm,paddingRight:`calc(${o.iconSizes.xl} + 2 * ${o.spacing.sm} + ${o.spacing.sm})`}}}}),t>o.breakpoints.hideWidgetDetails&&a(U,{children:a(N,{dirty:g,value:p,maxLength:B,type:"chat",inForm:!1})}),a(G,{children:a(F,{onClick:C,disabled:!g||I,extended:v,"data-testid":"stChatInputSubmitButton",children:a(K,{content:R,size:"xl",color:"inherit"})})})]})})}export{Z as default};
