import{n as t,aM as e,a8 as o,j as s,a2 as i}from"./index.DXat8gQf.js";import{P as l}from"./ProgressBar.ByDCgAp7.js";const d=t("div",{target:"eg8e9hd0"})(({theme:a})=>({paddingBottom:a.spacing.sm,lineHeight:"normal",color:e(a)}));function c({element:a,width:r}){return o("div",{className:"stProgress","data-testid":"stProgress",children:[s(d,{children:s(i,{source:a.text,allowHTML:!1,isLabel:!0})}),s(l,{value:a.value,width:r})]})}export{c as default};
