import{n as e,aW as t,i as d,R as l,a7 as c,bA as p,j as i,bB as g,a8 as S,a2 as u}from"./index.DXat8gQf.js";const b=e(t,{shouldForwardProp:d,target:"edrijs90"})(({theme:s,usingCustomTheme:r})=>({fontSize:s.fontSizes.sm,width:s.sizes.spinnerSize,height:s.sizes.spinnerSize,borderWidth:s.sizes.spinnerThickness,radius:s.radii.md,justifyContents:"center",padding:s.spacing.none,margin:s.spacing.none,borderColor:s.colors.borderColor,borderTopColor:r?s.colors.primary:s.colors.blue70,flexGrow:0,flexShrink:0})),C=e("div",{target:"edrijs91"})(({theme:s,width:r,cache:n})=>({width:r,...n?{paddingBottom:s.spacing.lg,background:`linear-gradient(to bottom, ${s.colors.bgColor} 0%, ${s.colors.bgColor} 80%, transparent 100%)`}:null})),f=e("div",{target:"edrijs92"})(({theme:s})=>({display:"flex",gap:s.spacing.sm,alignItems:"center",width:"100%"}));function y({width:s,element:r}){const{activeTheme:n}=l.useContext(c),a=!p(n),{cache:o}=r;return i(C,{className:g({stSpinner:!0,stCacheSpinner:o}),"data-testid":"stSpinner",width:s,cache:o,children:S(f,{children:[i(b,{usingCustomTheme:a}),i(u,{source:r.text,allowHTML:!1})]})})}export{y as default};
