import{n as i,r as s,j as e,a as d,P as m,b as p,F as P}from"./index.DXat8gQf.js";const x=i("div",{target:"e5hf4rh0"})({"@media print":{display:"none"}}),f=({className:t,scriptRunId:a,numParticles:r,numParticleTypes:o,ParticleComponent:n})=>e(x,{className:t,"data-testid":t,children:d(r).map(c=>{const l=Math.floor(Math.random()*o);return e(n,{particleType:l},a+c)})}),u=s.memo(f),y=({children:t})=>{var r;const a=(r=s.useContext(m))==null?void 0:r();return a?p.createPortal(t,a):e(P,{children:t})};export{u as P,y as R};
